import{O as r}from"./index.e8b1d57b.js";import{d as l,k as c,a5 as i,f as a,b as n,u as o,o as f,g as s,A as u,da as b}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ce725680-12af-45ee-b3c7-ff4f8c3d8bc1",e._sentryDebugIdIdentifier="sentry-dbid-ce725680-12af-45ee-b3c7-ff4f8c3d8bc1")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return c(async()=>{await new r().loginCallback()}),(t,d)=>(f(),i("div",null,[a(o(u),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.586aec29.js.map
