import{X as c,dL as s,dM as i}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="fedd3c27-98ff-4165-be14-fa42512c90d5",e._sentryDebugIdIdentifier="sentry-dbid-fedd3c27-98ff-4165-be14-fa42512c90d5")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:d}=s(i),y=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{y as D,r as M,o as Q,d as R,t as W};
//# sourceMappingURL=dayjs.ab138cea.js.map
