import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.91f2b134.js";import{d as i,ea as s,a,u as m,o as d}from"./jwt-decode.esm.7c3d38f1.js";import"./router.3e8ff207.js";import"./index.4934c987.js";import"./fetch.7006ac8a.js";import"./record.db662be3.js";import"./SaveButton.bbf2b3f1.js";import"./ExclamationCircleOutlined.d567dec0.js";import"./CrudView.01d9c2cc.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.818fdf18.js";import"./constants.a391dfa6.js";import"./url.9821d558.js";import"./PhDotsThreeVertical.vue.916081a4.js";import"./index.620d0c3a.js";import"./asyncComputed.3a882a5f.js";import"./polling.3aa7683f.js";import"./omniChatStore.a99d0c7d.js";import"./uuid.ee76ca1d.js";import"./PhCopySimple.vue.02ac676a.js";import"./PhPencil.vue.ab257059.js";import"./index.4320866d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="9d03a348-4f70-4ffd-885f-0f3bbc01a1ed",o._sentryDebugIdIdentifier="sentry-dbid-9d03a348-4f70-4ffd-885f-0f3bbc01a1ed")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(f,c)=>(d(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.b421ef48.js.map
