import{_ as r,o,a5 as n,a7 as s,e as d,h as a}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4894baf6-327a-43df-b5e1-6174e1493c95",e._sentryDebugIdIdentifier="sentry-dbid-4894baf6-327a-43df-b5e1-6174e1493c95")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},_={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},b={key:0};function y(e,t){return o(),n("div",i,[s(e.$slots,"sidebar",{},void 0,!0),d("section",f,[s(e.$slots,"navbar",{},void 0,!0),d("section",_,[d("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(o(),n("section",b,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const g=r(c,[["render",y],["__scopeId","data-v-fe23e6dd"]]);export{g as B};
//# sourceMappingURL=BaseLayout.535bb8d2.js.map
