import{O as d}from"./index.e8b1d57b.js";import{d as l,k as f,a5 as u,f as a,b as n,u as o,o as i,g as s,A as c,da as b}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9bb93a9c-2f46-4736-9f73-f4442f5f57c7",e._sentryDebugIdIdentifier="sentry-dbid-9bb93a9c-2f46-4736-9f73-f4442f5f57c7")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return f(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),u("div",null,[a(o(c),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.9a704236.js.map
