import{O as s}from"./OmniChat.99f94524.js";import{u as c}from"./omniChatStore.a99d0c7d.js";import{d as a,ea as i,u as t,o as f,a as d,h as l}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="15c3ef86-0371-473d-b2cf-534f64f7fc34",e._sentryDebugIdIdentifier="sentry-dbid-15c3ef86-0371-473d-b2cf-534f64f7fc34")}catch{}})();const b=a({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=c();return o.init("console",n),(u,p)=>t(o).controller&&t(o).repository?(f(),d(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):l("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.dc2d612d.js.map
