import{h as t}from"./router.3e8ff207.js";import"./jwt-decode.esm.7c3d38f1.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="24483864-3781-4c65-b2ea-5a48112d3d84",r._sentryDebugIdIdentifier="sentry-dbid-24483864-3781-4c65-b2ea-5a48112d3d84")}catch{}})();class s{async list(e){return t.get(`organizations/${e}/folders`)}async create(e){return t.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return t.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return t.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.7a845213.js.map
