import{h as t}from"./router.3e8ff207.js";import"./jwt-decode.esm.7c3d38f1.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="a42e70a8-6967-42d5-a1f6-e9a1aa1ec23f",a._sentryDebugIdIdentifier="sentry-dbid-a42e70a8-6967-42d5-a1f6-e9a1aa1ec23f")}catch{}})();class i{async create(e){return t.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return t.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return t.get(`organizations/${e}/members`)}async get(e,n){return t.get(`organizations/${e}/members/${n}`)}async update(e,n,r){return t.patch(`organizations/${e}/members/${n}`,r)}}export{i as M};
//# sourceMappingURL=member.bb4f5f75.js.map
