import{A as a}from"./index.604cd96f.js";import{d as o,c as r,a5 as p,f,u as c,e9 as l,h as d,o as i,_ as u}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="76ea6b36-333a-46ff-b753-cada444273f0",e._sentryDebugIdIdentifier="sentry-dbid-76ea6b36-333a-46ff-b753-cada444273f0")}catch{}})();const _=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),p("nav",{key:0,class:l(["p-steps",{"full-screen":!t.isPreview}])},[f(c(a),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}});const I=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{I as S};
//# sourceMappingURL=Steps.b9671dc4.js.map
