import{P as f}from"./PlayerNavbar.f11a7f90.js";import{d as g,e5 as h,ea as i,r as y,c as b,m as k,a5 as v,u as a,a as w,h as L,e as C,f as I,o as c,_ as N}from"./jwt-decode.esm.7c3d38f1.js";import{u as V}from"./workspaceStore.7db398b0.js";import"./userStore.5199e15f.js";import"./index.e8b1d57b.js";import"./metadata.8e64eff1.js";import"./PhWebhooksLogo.vue.d970c52c.js";import"./LoadingOutlined.e1cb768b.js";import"./PhSignOut.vue.a37651e9.js";import"./index.eb3cdc60.js";import"./url.9821d558.js";import"./colorHelpers.4c5dd1cc.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="9b73f8b7-df98-4d04-9e73-f2c769e12012",o._sentryDebugIdIdentifier="sentry-dbid-9b73f8b7-df98-4d04-9e73-f2c769e12012")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=i().path,n=y(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!i().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return c(),v("div",x,[a(t).state.workspace?(c(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.733270cf.js.map
