import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.2eb72172.js";import{d as m,e5 as f,ea as b,a5 as g,f as y,u as n,o as w,_ as k}from"./jwt-decode.esm.7c3d38f1.js";import{u as h}from"./workspaceStore.7db398b0.js";import"./index.e8b1d57b.js";import"./CircularLoading.d8164377.js";import"./Logo.96e2e5a1.js";import"./string.58b2ae3d.js";import"./index.4320866d.js";import"./userStore.5199e15f.js";import"./url.9821d558.js";import"./colorHelpers.4c5dd1cc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="279c3545-1503-433b-9db4-6b54c77edde1",e._sentryDebugIdIdentifier="sentry-dbid-279c3545-1503-433b-9db4-6b54c77edde1")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var c,d,p,u,i;return w(),g("div",v,[y(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-cb33c596"]]);export{U as default};
//# sourceMappingURL=Login.2c22ebcf.js.map
