import{d,a5 as a,e as s,a7 as f,e9 as n,o as l,_ as r}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f54288bc-6873-4978-8a39-cdbcefcbfe3d",t._sentryDebugIdIdentifier="sentry-dbid-f54288bc-6873-4978-8a39-cdbcefcbfe3d")}catch{}})();const c=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(l(),a("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[s("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[f(e.$slots,"default",{},void 0,!0)],2)],2))}});const u=r(c,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout.af5e006b.js.map
