import{i as h}from"./metadata.8e64eff1.js";import{W as k}from"./Watermark.8ae030fa.js";import{F as b}from"./PhArrowSquareOut.vue.c15f926b.js";import{d as v,e5 as w,c as x,r as C,u as e,a5 as f,f as p,b as r,h as D,o as a,a as n,g as m,T as y,aR as I,eb as z,de as _,ee as T,ec as F,e9 as B,_ as H}from"./jwt-decode.esm.7c3d38f1.js";import{u as L}from"./workspaceStore.7db398b0.js";import"./index.604caeb3.js";import{L as N}from"./LoadingOutlined.e1cb768b.js";import{C as S}from"./Card.781342be.js";import"./PhWebhooksLogo.vue.d970c52c.js";import"./index.e8b1d57b.js";import"./constants.a391dfa6.js";import"./userStore.5199e15f.js";import"./url.9821d558.js";import"./colorHelpers.4c5dd1cc.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="6ebf160d-be6c-4f91-a47d-b86a94736e2f",o._sentryDebugIdIdentifier="sentry-dbid-6ebf160d-be6c-4f91-a47d-b86a94736e2f")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const i=w(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(a(),f("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[m(" There are no forms available for you. ")]),_:1})):(a(!0),f(I,{key:1},z(u.value,t=>(a(),n(e(S),{key:t.id,class:B(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(T(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[m(F(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(b),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Y=H(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.b7e3b4e0.js.map
