import{N as k}from"./Navbar.07da2183.js";import{B as N}from"./BaseLayout.535bb8d2.js";import{C as I}from"./ContentLayout.af5e006b.js";import{C as _}from"./CrudView.01d9c2cc.js";import{a as O}from"./asyncComputed.3a882a5f.js";import{F as x}from"./PhArrowSquareOut.vue.c15f926b.js";import{G as R}from"./PhPencil.vue.ab257059.js";import{d as M,e5 as h,r as B,c as D,a5 as F,f as o,b as i,u as s,aR as V,o as f,a as $,cz as j,bJ as A,cy as E,h as G,M as L}from"./jwt-decode.esm.7c3d38f1.js";import"./router.3e8ff207.js";import{a as m}from"./organization.ef60f52a.js";import"./tables.910f41a2.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.6b2845ba.js";import"./constants.a391dfa6.js";import"./PhChats.vue.70cfce42.js";import"./PhSignOut.vue.a37651e9.js";import"./index.620d0c3a.js";import"./index.eb3cdc60.js";import"./omniChatStore.a99d0c7d.js";import"./record.db662be3.js";import"./uuid.ee76ca1d.js";import"./PhCopySimple.vue.02ac676a.js";import"./PhBookBookmark.vue.ab627aaf.js";import"./PhSparkle.vue.3967fcce.js";import"./index.2d170827.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.818fdf18.js";import"./url.9821d558.js";import"./PhDotsThreeVertical.vue.916081a4.js";import"./index.4934c987.js";import"./string.58b2ae3d.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},l=new Error().stack;l&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[l]="34ba9068-d340-4e1e-af98-0f7b2cd501ed",r._sentryDebugIdIdentifier="sentry-dbid-34ba9068-d340-4e1e-af98-0f7b2cd501ed")}catch{}})();const yt=M({__name:"Organizations",setup(r){const l=[{label:"My organizations",path:"/organizations"}],u=[{key:"name",label:"Organization Name"}],g=h(),{loading:y,result:b,refetch:v}=O(()=>m.list()),p=({key:e})=>{g.push({name:"organization",params:{organizationId:e}})},n=B({state:"idle"});function z(e){n.value={state:"renaming",organizationId:e.id,newName:e.name}}async function d(e){if(n.value.state==="renaming"&&e){const{organizationId:t,newName:a}=n.value;await m.rename(t,a),v()}n.value={state:"idle"}}const w=async e=>{const t=await m.create(e.name);p({key:t.id})},C=D(()=>{var e,t;return{columns:[{title:"Organization Name",align:"left"},{title:"Path"},{title:"",align:"right"}],rows:(t=(e=b.value)==null?void 0:e.map(a=>{var c;return{key:a.id,cells:[{type:"link",text:a.name,to:`/organizations/${encodeURIComponent(a.id)}`},{type:"text",text:(c=a.id)!=null?c:null},{type:"actions",actions:[{icon:x,label:"Go to projects",onClick:p},{icon:R,label:"Rename",onClick:()=>z(a)}]}]}}))!=null?t:[]}});return(e,t)=>(f(),F(V,null,[o(N,null,{navbar:i(()=>[o(k,{breadcrumb:l})]),content:i(()=>[o(I,null,{default:i(()=>[o(_,{"entity-name":"organization",loading:s(y),title:"My organizations",description:"An organization is your company\u2019s account. Manage editors, projects and billing.","create-button-text":"Create Organization","empty-title":"No organizations here yet",table:C.value,fields:u,create:w},null,8,["loading","table"])]),_:1})]),_:1}),o(s(L),{open:n.value.state==="renaming",title:"Rename organization",onCancel:t[1]||(t[1]=a=>d(!1)),onOk:t[2]||(t[2]=a=>d(!0))},{default:i(()=>[n.value.state==="renaming"?(f(),$(s(E),{key:0,layout:"vertical"},{default:i(()=>[o(s(j),{label:"New name"},{default:i(()=>[o(s(A),{value:n.value.newName,"onUpdate:value":t[0]||(t[0]=a=>n.value.newName=a)},null,8,["value"])]),_:1})]),_:1})):G("",!0)]),_:1},8,["open"])],64))}});export{yt as default};
//# sourceMappingURL=Organizations.aaec40f0.js.map
