import{f as c,e7 as o,eY as u}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="58c6a873-f1fd-4677-9fb9-06f45ec41bc6",e._sentryDebugIdIdentifier="sentry-dbid-58c6a873-f1fd-4677-9fb9-06f45ec41bc6")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(f){return Object.getOwnPropertyDescriptor(r,f).enumerable}))),n.forEach(function(f){a(e,f,r[f])})}return e}function a(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=l({},t,r.attrs);return c(o,l({},n,{icon:u}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.dab731fd.js.map
