import{y as n,z as r,B as o,C as d,P as p,D as c,E as b,F as f,G as i,H as m,I as u,J as g,K as y}from"./jwt-decode.esm.7c3d38f1.js";import{a as l,b as a}from"./workspaceStore.7db398b0.js";import{s as w}from"./index.e8b1d57b.js";import{_ as I}from"./App.vue_vue_type_style_index_0_lang.0e172cb4.js";import"./userStore.5199e15f.js";import"./url.9821d558.js";import"./colorHelpers.4c5dd1cc.js";import"./PlayerConfigProvider.0bdbb476.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="b38bb1fb-0733-43e8-96d4-c3deee2d2d50",t._sentryDebugIdIdentifier="sentry-dbid-b38bb1fb-0733-43e8-96d4-c3deee2d2d50")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const t=await l(),s=n(),e=r({render:()=>m(I)});o.init(),d(e,a,t),_.init(),e.use(a),e.use(s),e.use(p),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",b),e.component("Message",f),i(e,u),i(e,g),i(e,y)})();
//# sourceMappingURL=player.bb101dc7.js.map
