import{d as a,o,a5 as s,f as d,u as _,S as r,_ as c}from"./jwt-decode.esm.7c3d38f1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="484a8829-dc48-4bc0-8507-fab05e74578d",e._sentryDebugIdIdentifier="sentry-dbid-484a8829-dc48-4bc0-8507-fab05e74578d")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(_(r))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.4f07415a.js.map
